@@ -28,7 +28,7 @@ dt_col_merge_add <- function(data, col_merge) {
 
 dt_col_merge_entry <- function(vars, type, pattern = NULL, ...) {
 
-  if (!(type %in% c("merge", "merge_range", "merge_uncert"))) {
+  if (!(type %in% c("merge", "merge_range", "merge_uncert", "merge_n_pct"))) {
     stop("Invalid `type` provided.")
   }
 
