@@ -24,26 +24,34 @@ dt_footnotes_init <- function(data) {
     dt_footnotes_set(footnotes = ., data = data)
 }
 
-dt_footnotes_add <- function(data,
-                             locname,
-                             grpname,
-                             colname,
-                             locnum,
-                             rownum,
-                             footnotes) {
+dt_footnotes_add <- function(
+    data,
+    locname,
+    grpname,
+    colname,
+    locnum,
+    rownum,
+    footnotes
+) {
 
   data %>%
     dt_footnotes_get() %>%
     dplyr::bind_rows(
-      dplyr::tibble(
-        locname = locname,
+      expand.grid(
         grpname = grpname,
         colname = colname,
-        locnum = locnum,
         rownum = rownum,
-        colnum = NA_integer_,
-        footnotes = list(footnotes)
-      )
+        stringsAsFactors = FALSE
+      ) %>%
+        dplyr::as_tibble() %>%
+        dplyr::mutate(
+          locname = locname,
+          locnum = locnum,
+          colnum = NA_integer_,
+          footnotes = list(footnotes)
+        ) %>%
+        dplyr::distinct() %>%
+        dplyr::select(locname, grpname, colname, locnum, rownum, footnotes)
     ) %>%
     dt_footnotes_set(footnotes = ., data = data)
 }
