@@ -133,14 +133,14 @@ dt_stub_components <- function(data) {
 
   stub_components <- c()
 
-  if (any(!is.na(stub_df[["rowname"]]))) {
-    stub_components <- c(stub_components, "rowname")
-  }
-
   if (any(!is.na(stub_df[["group_id"]]))) {
     stub_components <- c(stub_components, "group_id")
   }
 
+  if (any(!is.na(stub_df[["rowname"]])) && !all(stub_df[["rowname"]] == "")) {
+    stub_components <- c(stub_components, "rowname")
+  }
+
   stub_components
 }
 
@@ -165,7 +165,7 @@ dt_stub_components_is_groupname <- function(stub_components) {
 # working with a table with rownames and groups
 dt_stub_components_is_rowname_groupname <- function(stub_components) {
 
-  identical(stub_components, c("rowname", "group_id"))
+  identical(stub_components, c("group_id", "rowname"))
 }
 
 dt_stub_components_has_rowname <- function(stub_components) {
