@@ -82,19 +82,30 @@ as.tags.gt_tbl <- function(x, ...) {
 
   # Attach the dependency to the HTML table
   html_tbl <-
-    htmltools::tagList(
+    htmltools::tags$div(
+      id = id,
       htmltools::tags$style(htmltools::HTML(css)),
-      htmltools::tags$div(
-        id = id,
-        style = htmltools::css(
-          `overflow-x` = container_overflow_x,
-          `overflow-y` = container_overflow_y,
-          width = container_width,
-          height = container_height
-        ),
-        htmltools::HTML(html_table)
-      )
+      style = htmltools::css(
+        `overflow-x` = container_overflow_x,
+        `overflow-y` = container_overflow_y,
+        width = container_width,
+        height = container_height
+      ),
+      htmltools::HTML(html_table)
     )
 
   html_tbl
 }
+
+#' Print RTF text
+#'
+#' @param x Object to be printed.
+#' @param ... Any additional parameters.
+#'
+#' @keywords internal
+#'
+#' @export
+print.rtf_text <- function(x, ...) {
+
+  cat(paste(x, collapse = "\n"))
+}
