@@ -1,5 +1,10 @@
 context("Ensuring that the `opt_*()` functions work properly")
 
+# Helper function to compare a contiguous set of HTML fragments with raw html
+html_fragment_within <- function(raw_html, ...) {
+  grepl(paste0("\\Q", c(...), "\\E", "[\\n\\s]*?", collapse = ""), raw_html, perl = TRUE)
+}
+
 test_that("The `opt_footnote_marks()` function sets the correct options", {
 
   set_marks <- c("*", "+", "~", "<", ">")
@@ -306,3 +311,109 @@ test_that("The `opt_table_outline()` function sets the correct options", {
   tbl %>% dt_options_get_value("table_border_right_width") %>% expect_equal("5px")
   tbl %>% dt_options_get_value("table_border_right_color") %>% expect_equal("#D3D3D3")
 })
+
+test_that("The `opt_table_font()` function sets the correct options", {
+
+  # Prepare a common gt table for all tests
+  tbl <- exibble %>% dplyr::select(char, time) %>% gt()
+
+  # Expect that a desired system font is placed at the
+  # head of the `font-family` font listing
+  tbl %>% opt_table_font(font = "Courier") %>%
+    compile_scss() %>% as.character() %>%
+    html_fragment_within(
+      ".gt_table {", "font-family: Courier, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;", "}"
+    ) %>% expect_true()
+
+  # Expect a replacement of the table's default
+  # `font-family` values when `add = FALSE`
+  tbl %>% opt_table_font(font = "Courier", add = FALSE) %>%
+    compile_scss() %>% as.character() %>%
+    html_fragment_within(
+      ".gt_table {", "font-family: Courier;", "}"
+    ) %>% expect_true()
+
+  # Expect that `weight` and `style` options are passed as CSS values
+  tbl %>% opt_table_font(font = "Courier", weight = "bold", style = "italic") %>%
+    compile_scss() %>% as.character() %>%
+    html_fragment_within(
+      "font-weight: bold;",
+      "font-style: italic;"
+    ) %>% expect_true()
+
+  # Expect that adding a font from the Google Fonts service
+  # is possible with the `google_font()` function
+  tbl %>% opt_table_font(font = google_font(name = "Dancing Script")) %>%
+    compile_scss() %>% as.character() %>%
+    html_fragment_within(
+      "@import url(\"https://fonts.googleapis.com/css2?family=Dancing+Script:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap\");",
+      ".gt_table {", "font-family: 'Dancing Script', -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;", "}"
+    ) %>% expect_true()
+
+  # Expect that equally valid inputs include wrapping in a list or `c()`
+  expect_equivalent(
+    tbl %>% opt_table_font(font = google_font(name = "Dancing Script")) %>% compile_scss(),
+    tbl %>% opt_table_font(font = list(google_font(name = "Dancing Script"))) %>% compile_scss(),
+    tbl %>% opt_table_font(font = c(google_font(name = "Dancing Script"))) %>% compile_scss()
+  )
+
+  # Expect `google_font()` with system fonts inside of
+  # a list or `c()`
+  tbl %>% opt_table_font(font = list(google_font(name = "Dancing Script"), "serif")) %>%
+    compile_scss() %>% as.character() %>%
+    html_fragment_within(
+      "@import url(\"https://fonts.googleapis.com/css2?family=Dancing+Script:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap\");",
+      ".gt_table {", "font-family: 'Dancing Script', serif, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;", "}"
+    ) %>% expect_true()
+
+  tbl %>% opt_table_font(font = c(google_font(name = "Dancing Script"), "serif")) %>%
+    compile_scss() %>% as.character() %>%
+    html_fragment_within(
+      "@import url(\"https://fonts.googleapis.com/css2?family=Dancing+Script:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap\");",
+      ".gt_table {", "font-family: 'Dancing Script', serif, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;", "}"
+    ) %>% expect_true()
+
+  # Expect any combination of vectors and `google_font()` calls inside
+  # of a list or `c()`
+  tbl %>% opt_table_font(font = list("serif", google_font(name = "Dancing Script"), "Courier", google_font(name = "Exo 2"))) %>%
+    compile_scss() %>% as.character() %>%
+    html_fragment_within(
+      "@import url(\"https://fonts.googleapis.com/css2?family=Dancing+Script:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap\");",
+      "@import url(\"https://fonts.googleapis.com/css2?family=Exo+2:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap\");",
+      ".gt_table {", "font-family: serif, 'Dancing Script', Courier, 'Exo 2', -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;", "}"
+    ) %>% expect_true()
+
+  tbl %>% opt_table_font(font = c("serif", google_font(name = "Dancing Script"), "Courier", google_font(name = "Exo 2"))) %>%
+    compile_scss() %>% as.character() %>%
+    html_fragment_within(
+      "@import url(\"https://fonts.googleapis.com/css2?family=Dancing+Script:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap\");",
+      "@import url(\"https://fonts.googleapis.com/css2?family=Exo+2:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap\");",
+      ".gt_table {", "font-family: serif, 'Dancing Script', Courier, 'Exo 2', -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;", "}"
+    ) %>% expect_true()
+
+  # Expect that font names are de-duplicated
+  tbl %>% opt_table_font(font = list(google_font(name = "Dancing Script"), "Courier", "Oxygen", "Courier")) %>%
+    compile_scss() %>% as.character() %>%
+    html_fragment_within(
+      "@import url(\"https://fonts.googleapis.com/css2?family=Dancing+Script:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap\");",
+      ".gt_table {",
+      "font-family: 'Dancing Script', Courier, Oxygen, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans', Arial, sans-serif;",
+      "}"
+    ) %>% expect_true()
+
+  # Expect that weights given as numbers or strings create the
+  # same outputs (e.g., 500 and "500")
+  expect_equivalent(
+    tbl %>% opt_table_font(font = google_font(name = "Dancing Script"), weight = 500) %>% compile_scss(),
+    tbl %>% opt_table_font(font = google_font(name = "Dancing Script"), weight = "500") %>% compile_scss()
+  )
+
+  # Expect an error if input to `font` is not a character vector
+  # or a list (but no errors otherwise)
+  expect_error(tbl %>% opt_table_font(font = c(TRUE, FALSE)))
+  expect_error(tbl %>% opt_table_font(font = 1:3))
+  expect_error(regexp = NA, tbl %>% opt_table_font(font = c("Courier", "Comic Sans MS")))
+  expect_error(regexp = NA, tbl %>% opt_table_font(font = list("Courier", "Comic Sans MS")))
+  expect_error(regexp = NA, tbl %>% opt_table_font(font = LETTERS))
+})
+
